@@ -1,9 +1,8 @@
 """
-todo: write a useful docstring
+A string similarity measure based on the Earth Mover's Distance
 """
 
-__version__ = '0.0.4'
-__description__ = 'Yet another string matching algorithm'
+__version__ = '0.0.5'
 
 from nmd.nmd import ngram_movers_distance
 from nmd.nmd_index import WordList
